@@ -23,15 +23,8 @@ public:
 
   OPVPSplashXPath *makeDashedPath(OPVPSplashState *state);
   void strokeNarrow(OPVPSplash *splash, OPVPSplashState *state);
-#if POPPLER_VERSION_MAJOR <= 0 && POPPLER_VERSION_MINOR < 19
-  void strokeWide(OPVPSplash *splash, OPVPSplashState *state);
-#endif
 private:
-#if POPPLER_VERSION_MAJOR > 0 || POPPLER_VERSION_MINOR >= 19
   OPVPSplashXPath() : SplashXPath(new SplashPath(), 0, 0, false) {};
-#else
-  OPVPSplashXPath() {};
-#endif
   OPVPSplashXPath(OPVPSplashXPath *xPath) : SplashXPath(xPath) {
   }
 };
